### Duos

All Types return a [ValueDict](https://github.com/cree-py/pynite/blob/master/docs/main.md#valuedict)

| Name | Description |
|------|-------------|
| duos.trn_rating | The Tracker Network Rating. |
| duos.score | The Score finishes. | ValueDict |
| duos.top1 | The Victory Royales finishes. |
| duos.top3 | The number of Top 3 wins finishes. |
| duos.top5 | The number of Top 5 wins finishes. |
| duos.top6 | The number of Top 6 wins finishes. |
| duos.top10 | The number of Top 10 finishes. |
| duos.top12 | The number of Top 12 finishes. |
| duos.top25 | The number of Top 25 finishes. |
| duos.kd | The Kill to Death ratio in duos. |
| duos.matches | The number of matches played. |
| duos.kills | The number of kills in Duos.
| duos.minutes_played | The number of minutes played in Duos.
| duos.kpm | The average number of kills per minute. |
| duos.kpg | The average number of kills per game. |
| duos.avg_time_played | The average amount of time for each match. |
| duos.score_per_match | The average score per match played |
| duos.score_per_min | The average score per minute played |
